import React, { FC } from 'react';
import { Dimensions, TouchableOpacity, View } from 'react-native';
import { CenterModalNavigationWrapperModel } from '../modalWrapperModels';
import { styles } from './styles';

const windowHeight = Dimensions.get('window').height;
const windowWidth = Dimensions.get('window').width;

export const CenterModalNavigationWrapper: FC<CenterModalNavigationWrapperModel> = ({
  onCloseModal,
  outsideCloseEnabled = true,
  modalHeight,
  modalWidth,
  backgroundColor= '#00000066',
  children,
}) => {
  const defaultModalHeight: number = typeof modalHeight === 'string'
    ? windowHeight * (parseFloat(modalHeight)/100)
    : modalHeight;

  const defaultModalWidth: number = typeof modalWidth === 'string'
    ? windowWidth * (parseFloat(modalWidth)/100)
    : modalWidth;

  const onClose = () => {
    onCloseModal?.();
  };

  return (
    <View style={[styles.centerModalWrapper, { backgroundColor, height: windowHeight,  width: windowWidth }]}>
      <TouchableOpacity style={{ height: windowHeight }} onPress={() => outsideCloseEnabled && onClose()} />
      <View
        style={
          [
            styles.centerModalWrapperContent,
            {
              height: defaultModalHeight,
              width: defaultModalWidth,
              transform: [{ translateY: -defaultModalHeight }],
              marginLeft: (windowWidth/2) - (defaultModalWidth/2),
            },
          ]}
      >
        {children}
      </View>
    </View>
  );
};
